#include "qrcodescandialog.h"
#include "ui_qrcodescandialog.h"

#include <QMessageBox>
#include <QtMultimedia/QCamera>
#include <QtMultimedia/QCameraInfo>


QrCodeScanDialog::QrCodeScanDialog(QWidget *parent)
        : QDialog(parent)
        , ui(new Ui::QrCodeScanDialog)
{
    ui->setupUi(this);
    this->setWindowTitle("Scan QR Code");

    auto cameras = QCameraInfo::availableCameras();
    if (cameras.count() < 1) {
        QMessageBox::warning(parent, "QR code scanner","No available cameras found.");
        return;
    }

    m_camera = new QCamera(cameras.first(), this);
    m_camera->setCaptureMode(QCamera::CaptureVideo);
    m_camera->setViewfinder(ui->viewfinder);


    m_scanner = new QrCodeScanner(this);
    m_scanner->setSource(m_camera);
    m_scanner->setEnabled(true);
    connect(m_scanner, &QrCodeScanner::decoded, this, &QrCodeScanDialog::onDecoded);
    m_camera->start();
}

void QrCodeScanDialog::onDecoded(int type, const QString &data) {
    decodedString = data;
    this->accept();
}

QrCodeScanDialog::~QrCodeScanDialog()
{
    delete m_camera;
    delete ui;
}